<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

if ( ! function_exists('is_plugin_active')){ include_once( ABSPATH . 'wp-admin/includes/plugin.php' ); }

class WPBForWPbakeryPro_Admin_Settings {

    private $settings_api;

    function __construct() {
        $this->settings_api = new WPBForWPbakery_Settings_API();

        add_action( 'admin_init', array( $this, 'admin_init' ) );
        add_action( 'admin_menu', array( $this, 'admin_menu' ), 20 );
        add_action( 'wsa_form_bottom_wpbforwpbakery_general_tabs', array( $this, 'render_general_tab_data' ) );
    }

    public function admin_init() {

        //set the settings
        $this->settings_api->set_sections( $this->admin_get_settings_sections() );
        $this->settings_api->set_fields( $this->admin_fields_settings() );

        //initialize settings
        $this->settings_api->admin_init();
    }

    // Plugins menu Register
    public function admin_menu() {
        add_submenu_page( 
        	'edit.php?post_type=wpbfwpb_template',
        	esc_html__( 'WC Page Builder Options', 'wpbforwpbakerypro' ),
        	esc_html__( 'WC Page Builder Options', 'wpbforwpbakerypro' ),
    		'manage_options',
    		'wpbforwpbakery_options',
    		array ( $this, 'plugin_page' )
    	);
    }

    // Options page Section register
    public function admin_get_settings_sections() {
        $sections = array(
        	array(
        	    'id'    => 'wpbforwpbakery_general_tabs',
        	    'title' => esc_html__( 'General', 'wpbforwpbakerypro' )
        	),

            array(
                'id'    => 'wpbforwpbakery_woo_template_tabs',
                'title' => esc_html__( 'WooCommerce Template', 'wpbforwpbakerypro' )
            ),

            array(
                'id'    => 'wpbforwpbakery_elements_tabs',
                'title' => esc_html__( 'Elements', 'wpbforwpbakerypro' )
            ),

            array(
                'id'    => 'wpbforwpbakery_rename_label_tabs',
                'title' => esc_html__( 'Rename Label', 'wpbforwpbakerypro' )
            ),
            
            array(
                'id'    => 'wpbforwpbakery_other_tabs',
                'title' => esc_html__( 'Others', 'wpbforwpbakerypro' )
            ),

        );
        return $sections;
    }

    // Options page field register
    protected function admin_fields_settings() {

        $settings_fields = array(

            'wpbforwpbakery_general_tabs' => array(),

            'wpbforwpbakery_woo_template_tabs' => array(

                array(
                    'name'  => 'enablecustomlayout',
                    'label'  => esc_html__( 'Enable / Disable Template Builder', 'wpbforwpbakerypro' ),
                    'desc'  => esc_html__( 'Enable', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                ),

                array(
                    'name'    => 'content_width',
                    'label'   => __( 'Content Width', 'wpbforwpbakerypro' ),
                    'desc'    => __( 'Sets the default width of the content area. e.g: 1170px', 'wpbforwpbakerypro' ),
                    'type'    => 'text',
                    'default' => '1170px',
                    'options' => wpbforwpbakerypro_post_list_arr('wpbfwpb_template')
                ),
                
                array(
                    'name'    => 'singleproductpage',
                    'label'   => esc_html__( 'Single Product Template', 'wpbforwpbakerypro' ),
                    'desc'    => esc_html__( 'You can select Custom Product details layout', 'wpbforwpbakerypro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => wpbforwpbakerypro_post_list_arr('wpbfwpb_template')
                ),

                array(
                    'name'    => 'productarchivepage',
                    'label'   => esc_html__( 'Product Archive Page Template', 'wpbforwpbakerypro' ),
                    'desc'    => esc_html__( 'You can select Custom Product Shop page layout', 'wpbforwpbakerypro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => wpbforwpbakerypro_post_list_arr('wpbfwpb_template')
                ),

                array(
                    'name'    => 'productcartpage',
                    'label'   => esc_html__( 'Cart Page Template', 'wpbforwpbakerypro' ),
                    'desc'    => esc_html__( 'You can select Custom cart page layout ', 'wpbforwpbakerypro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => wpbforwpbakerypro_post_list_arr('wpbfwpb_template'),
                    'class'=>'',
                ),

                array(
                    'name'    => 'productcheckoutpage',
                    'label'   => esc_html__( 'Checkout Page Template', 'wpbforwpbakerypro' ),
                    'desc'    => esc_html__( 'You can select Custom checkout page layout ', 'wpbforwpbakerypro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => wpbforwpbakerypro_post_list_arr('wpbfwpb_template'),
                    'class'=>'',
                ),

                array(
                    'name'    => 'productthankyoupage',
                    'label'   => esc_html__( 'Thank You Page Template', 'wpbforwpbakerypro' ),
                    'desc'    => esc_html__( 'You can select Custom thank you page layout ', 'wpbforwpbakerypro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => wpbforwpbakerypro_post_list_arr('wpbfwpb_template'),
                    'class'=>'',
                ),

                array(
                    'name'    => 'productmyaccountpage',
                    'label'   => esc_html__( 'My Account Page Template', 'wpbforwpbakerypro' ),
                    'desc'    => esc_html__( 'You can select Custom my account page layout ', 'wpbforwpbakerypro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => wpbforwpbakerypro_post_list_arr('wpbfwpb_template'),
                    'class'=>'',
                ),

                array(
                    'name'    => 'productmyaccountloginpage',
                    'label'   => esc_html__( 'My Account Login page Template', 'wpbforwpbakerypro' ),
                    'desc'    => esc_html__( 'You can select Custom my account login page layout ', 'wpbforwpbakerypro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => wpbforwpbakerypro_post_list_arr('wpbfwpb_template'),
                    'class'=>'',
                ),

            ),

            'wpbforwpbakery_elements_tabs' => array(

                array(
                    'name'  => 'wpb_product_data_tab',
                    'label'  => esc_html__( 'Product Tab', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_archive_product',
                    'label'  => esc_html__( 'Product Archive', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_archive_title',
                    'label'  => esc_html__( 'Archive Title', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_archive_header_description',
                    'label'  => esc_html__( 'Archive Header Description', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_title',
                    'label'  => esc_html__( 'Product Title', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_related',
                    'label'  => esc_html__( 'Related Product', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_add_to_cart',
                    'label'  => esc_html__( 'Add To Cart Button', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_additional_information',
                    'label'  => esc_html__( 'Additional Information', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_data_tab',
                    'label'  => esc_html__( 'Product data Tab', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_description',
                    'label'  => esc_html__( 'Product Description', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_short_description',
                    'label'  => esc_html__( 'Product Short Description', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_price',
                    'label'  => esc_html__( 'Product Price', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_rating',
                    'label'  => esc_html__( 'Product Rating', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_reviews',
                    'label'  => esc_html__( 'Product Reviews', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_image',
                    'label'  => esc_html__( 'Product Image', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_upsell',
                    'label'  => esc_html__( 'Product Upsell', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_stock',
                    'label'  => esc_html__( 'Product Stock Status', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_product_meta',
                    'label'  => esc_html__( 'Product Meta Info', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_cart_table',
                    'label'  => esc_html__( 'Product Cart Table ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_cart_total',
                    'label'  => esc_html__( 'Product Cart Total ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_cross_sell',
                    'label'  => esc_html__( 'Product Cross Sell ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_checkout_additional_form',
                    'label'  => esc_html__( 'Checkout Additional.. ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_checkout_billing',
                    'label'  => esc_html__( 'Checkout Billing Form ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_checkout_shipping_form',
                    'label'  => esc_html__( 'Checkout Shipping Form ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_checkout_payment',
                    'label'  => esc_html__( 'Checkout Payment ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_order_review',
                    'label'  => esc_html__( 'Checkout Order Review ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_myaccount_dashboard',
                    'label'  => esc_html__( 'Myaccount Dashboard ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_myaccount_download',
                    'label'  => esc_html__( 'Myaccount Download ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_myaccount_edit_account',
                    'label'  => esc_html__( 'My Account ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_myaccount_address',
                    'label'  => esc_html__( 'Myaccount Address ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_myaccount_login_form',
                    'label'  => esc_html__( 'Login Form ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_myaccount_register_form',
                    'label'  => esc_html__( 'Register Form ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_myaccount_logout',
                    'label'  => esc_html__( 'Myaccount Logout ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_myaccount_order',
                    'label'  => esc_html__( 'Myaccount Order ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_thankyou_order',
                    'label'  => esc_html__( 'Thankyou Order ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_thankyou_customer_address_details',
                    'label'  => esc_html__( 'Thankyou Cus.. Address ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_thankyou_order_details',
                    'label'  => esc_html__( 'Thankyou Order Details ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

                array(
                    'name'  => 'wpb_social_shere',
                    'label'  => esc_html__( 'Product Social Share ', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'=>'wpbforwpbakery_table_row',
                ),

            ),

            'wpbforwpbakery_rename_label_tabs' => array(
                array(
                    'name'  => 'enablerenamelabel',
                    'label'  => __( 'Enable / Disable Rename Label', 'wpbforwpbakerypro' ),
                    'desc'  => __( 'Enable', 'wpbforwpbakerypro' ),
                    'type'  => 'checkbox',
                    'default' => 'off',
                    'class'   =>'wpbforwpbakery_table_row enablerenamelabel',
                ),

                array(
                    'name'      => 'shop_page_heading',
                    'headding'  => __( 'Shop Page', 'wpbforwpbakerypro' ),
                    'type'      => 'title',
                    'class'     => 'htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'shop_add_to_cart_txt',
                    'label'       => __( 'Add to Cart Button Text', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the Add to Cart button text for the Shop page.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Add to Cart', 'wpbforwpbakerypro' ),
                    'class'       => 'htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'      => 'product_details_page_heading',
                    'headding'  => __( 'Product Details Page', 'wpbforwpbakerypro' ),
                    'type'      => 'title',
                    'class'     => 'htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'add_to_cart_txt',
                    'label'       => __( 'Add to Cart Button Text', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the Add to Cart button text for the Product details page.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Add to Cart', 'wpbforwpbakerypro' ),
                    'class'       => 'htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'description_tab_menu_titlep',
                    'label'       => __( 'Description', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the tab title for the product description.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Description', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'additional_information_tab_menu_titlep',
                    'label'       => __( 'Additional Information', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the tab title for the product additional information', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Additiona information', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'reviews_tab_menu_titlep',
                    'label'       => __( 'Reviews', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the tab title for the product review <span class="proelement">( Pro )</span>', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Reviews', 'wpbforwpbakerypro' ),
                    'class'       =>'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'      => 'checkout_page_headingp',
                    'headding'  => __( 'Checkout Page', 'wpbforwpbakerypro' ),
                    'type'      => 'title',
                    'class'     => 'htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'checkout_firstname_labelp',
                    'label'       => __( 'First name', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the label for the First name field', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'First name', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'checkout_lastname_labelp',
                    'label'       => __( 'Last name', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the label for the Last name field', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Last name', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'checkout_company_labelp',
                    'label'       => __( 'Company name', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the label for the Company field.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Company name', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'checkout_address_1_labelp',
                    'label'       => __( 'Street address', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the label for the Street address field.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Street address', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'checkout_city_labelp',
                    'label'       => __( 'Town / City', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the label for the Town/City field.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Town / City', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'checkout_postcode_labelp',
                    'label'       => __( 'Postcode / ZIP', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the label for the Postcode / ZIP field.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Postcode / ZIP', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'checkout_state_labelp',
                    'label'       => __( 'State', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the label for the State field.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'State', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'checkout_phone_labelp',
                    'label'       => __( 'Phone', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the label for the Phone field.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Phone', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'checkout_email_labelp',
                    'label'       => __( 'Email address', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the label for the Email address field.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Email address', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'checkout_country_labelp',
                    'label'       => __( 'Country', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the label for the Country field.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Country', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'checkout_ordernote_labelp',
                    'label'       => __( 'Order Note', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the label for the Order notes field.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Order notes', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),

                array(
                    'name'        => 'checkout_placeorder_btn_txtp',
                    'label'       => __( 'Place order', 'wpbforwpbakerypro' ),
                    'desc'        => __( 'Change the label for the Place order field.', 'wpbforwpbakerypro' ),
                    'type'        => 'text',
                    'placeholder' => __( 'Place order', 'wpbforwpbakerypro' ),
                    'class'       => 'pro htp_show_if_enablerenamelabel_1',
                ),                
            ),

            'wpbforwpbakery_other_tabs' => array(
                array(
                    'name'   => 'ajaxcart_singleproduct',
                    'label'  => esc_html__( 'Single Product Ajax Add To Cart', 'wpbforwpbakerypro' ),
                    'desc'  => wp_kses_post( 'AJAX Add to Cart on Single Product page', 'wpbforwpbakerypro' ),
                    'type'   => 'checkbox',
                    'default'=> 'off',
                    'class'  =>'wpbforwpbakerypro_table_row',
                ),

                array(
                    'name'   => 'single_product_sticky_add_to_cart',
                    'label'  => esc_html__( 'Single Product Sticky Add To Cart', 'wpbforwpbakerypro' ),
                    'desc'  => wp_kses_post( 'Sticky Add to Cart on Single Product page', 'wpbforwpbakerypro' ),
                    'type'   => 'checkbox',
                    'default'=> 'off',
                    'class'  =>'wpbforwpbakerypro_table_row',
                ),

                array(
                    'name'   => 'redirect_add_to_cart',
                    'label'  => esc_html__( 'Redirect to Checkout on Add to Cart', 'wpbforwpbakerypro' ),
                    'type'   => 'checkbox',
                    'default'=> 'off',
                    'class'  =>'wpbforwpbakerypro_table_row',
                ),

                array(
                    'name'   => 'mini_side_cart',
                    'label'  => esc_html__( 'Side Mini Cart', 'wpbforwpbakerypro' ),
                    'type'   => 'checkbox',
                    'default'=> 'off',
                    'class'  =>'wpbforwpbakerypro_table_row side_mini_cart',
                ),

                array(
                    'name'    => 'mini_cart_position',
                    'label'   => esc_html__( 'Mini Cart Position', 'wpbforwpbakerypro' ),
                    'desc'    => esc_html__( 'Set the position of the Mini Cart .', 'wpbforwpbakerypro' ),
                    'type'    => 'select',
                    'default' => 'left',
                    'options' => array(
                        'left'   => esc_html__( 'Left','wpbforwpbakerypro' ),
                        'right'  => esc_html__( 'Right','wpbforwpbakerypro' ),
                    ),
                    'class'  =>'htp_show_if_side_mini_cart_1',
                ),

                array(
                    'name'    => 'mini_cart_icon',
                    'label'   => esc_html__( 'Mini Cart Icon', 'wpbforwpbakerypro' ),
                    'desc'    => esc_html__( 'You can manage the side mini cart toggler icon.', 'wpbforwpbakerypro' ),
                    'type'    => 'text',
                    'default' => 'sli sli-basket-loaded',
                    'class'  => 'wpbforwpbakery_icon_picker htp_show_if_side_mini_cart_1',
                ),

                array(
                    'name'  => 'mini_cart_icon_cowool
                    lor',
                    'label' => __( 'Mini cart icon color', 'wpbforwpbakerypro' ),
                    'desc' => wp_kses_post( 'Side mini cart icon color', 'wpbforwpbakerypro' ),
                    'type' => 'color',
                    'class'  =>'htp_show_if_side_mini_cart_1',
                ),

                array(
                    'name'  => 'mini_cart_icon_color',
                    'label' => __( 'Mini cart icon color', 'wpbforwpbakerypro' ),
                    'desc' => wp_kses_post( 'Side mini cart icon color', 'wpbforwpbakerypro' ),
                    'type' => 'color',
                    'class'  =>'htp_show_if_side_mini_cart_1',
                ),

                array(
                    'name'  => 'mini_cart_icon_bg_color',
                    'label' => __( 'Mini cart icon background color', 'wpbforwpbakerypro' ),
                    'desc' => wp_kses_post( 'Side mini cart icon background color', 'wpbforwpbakerypro' ),
                    'type' => 'color',
                    'class'  =>'htp_show_if_side_mini_cart_1',
                ),

                array(
                    'name'  => 'mini_cart_icon_border_color',
                    'label' => __( 'Mini cart icon border color', 'wpbforwpbakerypro' ),
                    'desc' => wp_kses_post( 'Side mini cart icon border color', 'wpbforwpbakerypro' ),
                    'type' => 'color',
                    'class'  =>'htp_show_if_side_mini_cart_1',
                ),

                array(
                    'name'  => 'mini_cart_counter_color',
                    'label' => __( 'Mini cart counter color', 'wpbforwpbakerypro' ),
                    'desc' => wp_kses_post( 'Side mini cart counter color', 'wpbforwpbakerypro' ),
                    'type' => 'color',
                    'class'  =>'htp_show_if_side_mini_cart_1',
                ), 
            ),

            'wpbforwpbakery_template_library_tabs' => array(),
            'wpbforwpbakery_buy_pro_tabs' => array(),

        );
        
        return array_merge( $settings_fields );
    }

    // General tab
    public function render_general_tab_data(){
        ob_start();
        ?>
            <div class="wpbforwpbakery-general-tabs">

                <div class="wpbforwpbakery-document-section">
                    <div class="wpbforwpbakery-column">
                        <a href="//hasthemes.com/how-to-use-woocommerce-page-builder-for-wpbakery/" target="_blank">
                            <img src="<?php echo WPBFORWPBAKERY_PRO_ADDONS_PL_URL; ?>/includes/admin/assets/images/video-tutorial.jpg" alt="<?php esc_attr_e( 'Video Tutorial', 'wpbforwpbakerypro' ); ?>">
                        </a>
                    </div>
                    <div class="wpbforwpbakery-column">
                        <a href="//hasthemes.com/contact-us/" target="_blank">
                            <img src="<?php echo WPBFORWPBAKERY_PRO_ADDONS_PL_URL; ?>/includes/admin/assets/images/genral-contact-us.jpg" alt="<?php esc_attr_e( 'Contact Us', 'wpbforwpbakerypro' ); ?>">
                        </a>
                    </div>
                </div>

            </div>
        <?php
        echo ob_get_clean();
    }

    public function plugin_page() {

        echo '<div class="wrap">';
            echo '<h2>'. esc_html__( 'WooCommerce Page Builder Settings','wpbforwpbakerypro' ). '</h2>';
            $this->save_message();
            $this->settings_api->show_navigation();
            $this->settings_api->show_forms();
        echo '</div>';

    }

    public function save_message() {
        if( isset($_GET['settings-updated']) ) { ?>
            <div class="updated notice is-dismissible"> 
                <p><strong><?php esc_html_e('Successfully Settings Saved.', 'wpbforwpbakerypro') ?></strong></p>
            </div>
            <?php
        }
    }

}

new WPBForWPbakeryPro_Admin_Settings();