<?php
namespace WPBForWPbakeryPro;

defined( 'ABSPATH' ) || exit;

/**
 * WC_Admin_Assets Class.
 */
class Side_Mini_Cart {
    /**
     * Constructor.
     */
    public function __construct() {
        // Frontend assets
        add_action( 'wp_enqueue_scripts', array( $this, 'frontend_assets' ) );

        // Admin assets
        add_action( 'admin_enqueue_scripts', array( $this, 'admin_assets' ) );

        // Render markup
        add_action( 'wp_footer', array( $this, 'render_markup' ) );

        // Refresh WC fragments
        add_filter( 'woocommerce_add_to_cart_fragments', array( $this, 'refresh_wc_fragments'), 10, 1 );
    }

    /**
     * Frontend assets
     */
    public function frontend_assets() {
        // Styles
        wp_enqueue_style( 'simple-line-icons', WPBFORWPBAKERY_PRO_ADDONS_PL_URL.'/assets/css/simple-line-icons.css', array(), WPBFORWPBAKERY_PRO_VERSION );
        wp_enqueue_style( 'wpbforwpbakery-side-mini-cart', WPBFORWPBAKERY_PRO_ADDONS_PL_URL.'/assets/css/side-mini-cart.css' );

        // Scripts
        wp_enqueue_script( 'wpbforwpbakery-side-mini-cart', WPBFORWPBAKERY_PRO_ADDONS_PL_URL.'/assets/js/side-mini-cart.js', array('jquery'), WPBFORWPBAKERY_PRO_VERSION, true );

        // Inline Style
        wp_add_inline_style( 'wpbforwpbakery-side-mini-cart', $this->get_inline_styles() );

        // Localize
        if( isset( $_POST['add-to-cart'] ) ){
            $added_to_cart = true; 
        } else{ 
            $added_to_cart = false;
        }

        $localize_vars = array(
            'added_to_cart' => $added_to_cart,
        );
        wp_localize_script( 'wpbforwpbakery-side-mini-cart', 'wpbforwpbakery_side_mini_cart_params', $localize_vars );
    }

    /**
     * Admin assets
     */
    public function admin_assets( $screen ) {
        if($screen != 'wpbfwpb_template_page_wpbforwpbakery_options'){
            return;
        }

        // Styles
        wp_enqueue_style( 'jquery-fonticonpicker', WPBFORWPBAKERY_PRO_ADDONS_PL_URL.'/assets/iconpicker/css/jquery.fonticonpicker.min.css', array(), WPBFORWPBAKERY_PRO_VERSION );
        wp_enqueue_style( 'jquery-fonticonpicker-bootstrap', WPBFORWPBAKERY_PRO_ADDONS_PL_URL.'/assets/iconpicker/css/jquery.fonticonpicker.bootstrap.min.css', array(), WPBFORWPBAKERY_PRO_VERSION );
        wp_enqueue_style( 'simple-line-icons', WPBFORWPBAKERY_PRO_ADDONS_PL_URL.'/assets/css/simple-line-icons.css', array(), WPBFORWPBAKERY_PRO_VERSION );

        // Script
        wp_enqueue_script( 'jquery-fonticonpicker', WPBFORWPBAKERY_PRO_ADDONS_PL_URL.'/assets/iconpicker/js/jquery.fonticonpicker.min.js', array('jquery'), WPBFORWPBAKERY_PRO_VERSION );
        add_action( 'admin_footer', function(){
            ?>
                <script type="text/javascript">
                    // Icon Picker
                    console.log(wpbforwpbakery_side_mini_cart_admin_params.iconset);
                    jQuery('.wpbforwpbakery_icon_picker .regular-text').fontIconPicker({
                        source: wpbforwpbakery_side_mini_cart_admin_params.iconset,
                        emptyIcon: true,
                        hasSearch: true,
                        theme: 'fip-bootstrap'
                    });
                </script>
            <?php 
        });

        // Localize
        $localize_vars = array(
            'iconset' => $this->get_icons_list()
        );
        wp_localize_script( 'jquery-fonticonpicker', 'wpbforwpbakery_side_mini_cart_admin_params', $localize_vars );
    }

    /**
     * Filter inline css
     */
    public function filter_inline_css( $key, $tab, $css_attr ) {
        $field_value = !empty( wpbforwpbakerypro_get_option( $key, $tab ) ) ? wpbforwpbakerypro_get_option( $key, $tab ) : '';

        if( !empty( $field_value ) ){
            $css_attr .= ":{$field_value}";
            return $css_attr.';';
        }else{
            return false;
        }
    }

    /**
     * Generate & return inline styles
     */
    public function get_inline_styles() {
        $icon_color = $this->filter_inline_css('mini_cart_icon_color','wpbforwpbakery_other_tabs','color');
        $icon_bg = $this->filter_inline_css('mini_cart_icon_bg_color','wpbforwpbakery_other_tabs','background-color');
        $icon_border = $this->filter_inline_css('mini_cart_icon_border_color','wpbforwpbakery_other_tabs','border-color');

        $counter_color = $this->filter_inline_css('mini_cart_counter_color','wpbforwpbakery_other_tabs','color');
        $counter_bg_color = $this->filter_inline_css('mini_cart_counter_bg_color','wpbforwpbakery_other_tabs','background-color');

        $custom_css = "
            .wpbforwpbakery_mini_cart_icon_area{
                {$icon_color}
                {$icon_bg}
                {$icon_border}
            }
            .wpbforwpbakery_mini_cart_counter{
                {$counter_color}
                {$counter_bg_color}
            }
        ";

        return $custom_css;
    }

    /**
     * Icons list for icon picker
     */
    public function get_icons_list() {
        $simple_line_icons = [
            'sli-user' => 'sli sli-user',
            'sli-people' => 'sli sli-people',
            'sli-user-female' => 'sli sli-user-female',
            'sli-user-follow' => 'sli sli-user-follow',
            'sli-user-following' => 'sli sli-user-following',
            'sli-user-unfollow' => 'sli sli-user-unfollow',
            'sli-login' => 'sli sli-login',
            'sli-logout' => 'sli sli-logout',
            'sli-emotsmile' => 'sli sli-emotsmile',
            'sli-phone' => 'sli sli-phone',
            'sli-call-end' => 'sli sli-call-end',
            'sli-call-in' => 'sli sli-call-in',
            'sli-call-out' => 'sli sli-call-out',
            'sli-map' => 'sli sli-map',
            'sli-location-pin' => 'sli sli-location-pin',
            'sli-direction' => 'sli sli-direction',
            'sli-directions' => 'sli sli-directions',
            'sli-compass' => 'sli sli-compass',
            'sli-layers' => 'sli sli-layers',
            'sli-menu' => 'sli sli-menu',
            'sli-list' => 'sli sli-list',
            'sli-options-vertical' => 'sli sli-options-vertical',
            'sli-options' => 'sli sli-options',
            'sli-arrow-down' => 'sli sli-arrow-down',
            'sli-arrow-left' => 'sli sli-arrow-left',
            'sli-arrow-right' => 'sli sli-arrow-right',
            'sli-arrow-up' => 'sli sli-arrow-up',
            'sli-arrow-up-circle' => 'sli sli-arrow-up-circle',
            'sli-arrow-left-circle' => 'sli sli-arrow-left-circle',
            'sli-arrow-right-circle' => 'sli sli-arrow-right-circle',
            'sli-arrow-down-circle' => 'sli sli-arrow-down-circle',
            'sli-check' => 'sli sli-check',
            'sli-clock' => 'sli sli-clock',
            'sli-plus' => 'sli sli-plus',
            'sli-minus' => 'sli sli-minus',
            'sli-close' => 'sli sli-close',
            'sli-event' => 'sli sli-event',
            'sli-exclamation' => 'sli sli-exclamation',
            'sli-organization' => 'sli sli-organization',
            'sli-trophy' => 'sli sli-trophy',
            'sli-screen-smartphone' => 'sli sli-screen-smartphone',
            'sli-screen-desktop' => 'sli sli-screen-desktop',
            'sli-plane' => 'sli sli-plane',
            'sli-notebook' => 'sli sli-notebook',
            'sli-mustache' => 'sli sli-mustache',
            'sli-mouse' => 'sli sli-mouse',
            'sli-magnet' => 'sli sli-magnet',
            'sli-energy' => 'sli sli-energy',
            'sli-disc' => 'sli sli-disc',
            'sli-cursor' => 'sli sli-cursor',
            'sli-cursor-move' => 'sli sli-cursor-move',
            'sli-crop' => 'sli sli-crop',
            'sli-chemistry' => 'sli sli-chemistry',
            'sli-speedometer' => 'sli sli-speedometer',
            'sli-shield' => 'sli sli-shield',
            'sli-screen-tablet' => 'sli sli-screen-tablet',
            'sli-magic-wand' => 'sli sli-magic-wand',
            'sli-hourglass' => 'sli sli-hourglass',
            'sli-graduation' => 'sli sli-graduation',
            'sli-ghost' => 'sli sli-ghost',
            'sli-game-controller' => 'sli sli-game-controller',
            'sli-fire' => 'sli sli-fire',
            'sli-eyeglass' => 'sli sli-eyeglass',
            'sli-envelope-open' => 'sli sli-envelope-open',
            'sli-envelope-letter' => 'sli sli-envelope-letter',
            'sli-bell' => 'sli sli-bell',
            'sli-badge' => 'sli sli-badge',
            'sli-anchor' => 'sli sli-anchor',
            'sli-wallet' => 'sli sli-wallet',
            'sli-vector' => 'sli sli-vector',
            'sli-speech' => 'sli sli-speech',
            'sli-puzzle' => 'sli sli-puzzle',
            'sli-printer' => 'sli sli-printer',
            'sli-present' => 'sli sli-present',
            'sli-playlist' => 'sli sli-playlist',
            'sli-pin' => 'sli sli-pin',
            'sli-picture' => 'sli sli-picture',
            'sli-handbag' => 'sli sli-handbag',
            'sli-globe-alt' => 'sli sli-globe-alt',
            'sli-globe' => 'sli sli-globe',
            'sli-folder-alt' => 'sli sli-folder-alt',
            'sli-folder' => 'sli sli-folder',
            'sli-film' => 'sli sli-film',
            'sli-feed' => 'sli sli-feed',
            'sli-drop' => 'sli sli-drop',
            'sli-drawer' => 'sli sli-drawer',
            'sli-docs' => 'sli sli-docs',
            'sli-doc' => 'sli sli-doc',
            'sli-diamond' => 'sli sli-diamond',
            'sli-cup' => 'sli sli-cup',
            'sli-calculator' => 'sli sli-calculator',
            'sli-bubbles' => 'sli sli-bubbles',
            'sli-briefcase' => 'sli sli-briefcase',
            'sli-book-open' => 'sli sli-book-open',
            'sli-basket-loaded' => 'sli sli-basket-loaded',
            'sli-basket' => 'sli sli-basket',
            'sli-bag' => 'sli sli-bag',
            'sli-action-undo' => 'sli sli-action-undo',
            'sli-action-redo' => 'sli sli-action-redo',
            'sli-wrench' => 'sli sli-wrench',
            'sli-umbrella' => 'sli sli-umbrella',
            'sli-trash' => 'sli sli-trash',
            'sli-tag' => 'sli sli-tag',
            'sli-support' => 'sli sli-support',
            'sli-frame' => 'sli sli-frame',
            'sli-size-fullscreen' => 'sli sli-size-fullscreen',
            'sli-size-actual' => 'sli sli-size-actual',
            'sli-shuffle' => 'sli sli-shuffle',
            'sli-share-alt' => 'sli sli-share-alt',
            'sli-share' => 'sli sli-share',
            'sli-rocket' => 'sli sli-rocket',
            'sli-question' => 'sli sli-question',
            'sli-pie-chart' => 'sli sli-pie-chart',
            'sli-pencil' => 'sli sli-pencil',
            'sli-note' => 'sli sli-note',
            'sli-loop' => 'sli sli-loop',
            'sli-home' => 'sli sli-home',
            'sli-grid' => 'sli sli-grid',
            'sli-graph' => 'sli sli-graph',
            'sli-microphone' => 'sli sli-microphone',
            'sli-music-tone-alt' => 'sli sli-music-tone-alt',
            'sli-music-tone' => 'sli sli-music-tone',
            'sli-earphones-alt' => 'sli sli-earphones-alt',
            'sli-earphones' => 'sli sli-earphones',
            'sli-equalizer' => 'sli sli-equalizer',
            'sli-like' => 'sli sli-like',
            'sli-dislike' => 'sli sli-dislike',
            'sli-control-start' => 'sli sli-control-start',
            'sli-control-rewind' => 'sli sli-control-rewind',
            'sli-control-play' => 'sli sli-control-play',
            'sli-control-pause' => 'sli sli-control-pause',
            'sli-control-forward' => 'sli sli-control-forward',
            'sli-control-end' => 'sli sli-control-end',
            'sli-volume-1' => 'sli sli-volume-1',
            'sli-volume-2' => 'sli sli-volume-2',
            'sli-volume-off' => 'sli sli-volume-off',
            'sli-calendar' => 'sli sli-calendar',
            'sli-bulb' => 'sli sli-bulb',
            'sli-chart' => 'sli sli-chart',
            'sli-ban' => 'sli sli-ban',
            'sli-bubble' => 'sli sli-bubble',
            'sli-camrecorder' => 'sli sli-camrecorder',
            'sli-camera' => 'sli sli-camera',
            'sli-cloud-download' => 'sli sli-cloud-download',
            'sli-cloud-upload' => 'sli sli-cloud-upload',
            'sli-envelope' => 'sli sli-envelope',
            'sli-eye' => 'sli sli-eye',
            'sli-flag' => 'sli sli-flag',
            'sli-heart' => 'sli sli-heart',
            'sli-info' => 'sli sli-info',
            'sli-key' => 'sli sli-key',
            'sli-link' => 'sli sli-link',
            'sli-lock' => 'sli sli-lock',
            'sli-lock-open' => 'sli sli-lock-open',
            'sli-magnifier' => 'sli sli-magnifier',
            'sli-magnifier-add' => 'sli sli-magnifier-add',
            'sli-magnifier-remove' => 'sli sli-magnifier-remove',
            'sli-paper-clip' => 'sli sli-paper-clip',
            'sli-paper-plane' => 'sli sli-paper-plane',
            'sli-power' => 'sli sli-power',
            'sli-refresh' => 'sli sli-refresh',
            'sli-reload' => 'sli sli-reload',
            'sli-settings' => 'sli sli-settings',
            'sli-star' => 'sli sli-star',
            'sli-symbol-female' => 'sli sli-symbol-female',
            'sli-symbol-male' => 'sli sli-symbol-male',
            'sli-target' => 'sli sli-target',
            'sli-credit-card' => 'sli sli-credit-card',
            'sli-paypal' => 'sli sli-paypal',
            'sli-social-tumblr' => 'sli sli-social-tumblr',
            'sli-social-twitter' => 'sli sli-social-twitter',
            'sli-social-facebook' => 'sli sli-social-facebook',
            'sli-social-instagram' => 'sli sli-social-instagram',
            'sli-social-linkedin' => 'sli sli-social-linkedin',
            'sli-social-pinterest' => 'sli sli-social-pinterest',
            'sli-social-github' => 'sli sli-social-github',
            'sli-social-google' => 'sli sli-social-google',
            'sli-social-reddit' => 'sli sli-social-reddit',
            'sli-social-skype' => 'sli sli-social-skype',
            'sli-social-dribbble' => 'sli sli-social-dribbble',
            'sli-social-behance' => 'sli sli-social-behance',
            'sli-social-foursqare' => 'sli sli-social-foursqare',
            'sli-social-soundcloud' => 'sli sli-social-soundcloud',
            'sli-social-spotify' => 'sli sli-social-spotify',
            'sli-social-stumbleupon' => 'sli sli-social-stumbleupon',
            'sli-social-youtube' => 'sli sli-social-youtube',
            'sli-social-dropbox' => 'sli sli-social-dropbox',
            'sli-social-vkontakte' => 'sli sli-social-vkontakte',
            'sli-social-steam' => 'sli sli-social-steam',
        ];

        $icons_list = array();
        $icons_list['SimpleLineIcon'] = $simple_line_icons;

        return $icons_list;
    }

    /**
     * Render markup
     */
    public function render_markup() {
        $cart_position = wpbforwpbakerypro_get_option( 'mini_cart_position', 'wpbforwpbakery_other_tabs', 'left' );
        $cart_icon = wpbforwpbakerypro_get_option( 'mini_cart_icon', 'wpbforwpbakery_other_tabs', 'sli-basket-loaded' );
        ?>
        <div class="wpbforwpbakery_mini_cart_area wpbforwpbakery_mini_cart_pos_<?php echo esc_attr( $cart_position ); ?>">
            <div class="wpbforwpbakery_mini_cart_icon_area">
                <?php $count_item = WC()->cart->get_cart_contents_count(); ?>
                <span class="wpbforwpbakery_mini_cart_counter"><?php echo $count_item; ?></span>
                <span class="wpbforwpbakery_mini_cart_icon"><i class="<?php echo esc_attr( $cart_icon ); ?>"></i></span>
            </div>
            <div class="wpbforwpbakery_body_opacity"></div>
            <div class="wpbforwpbakery_cart_content_container">
                <?php
                    wc_get_template( 'tmpl-mini-cart-content.php', array(), '', WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/templates/' );
                ?>
            </div>
        </div>
        <?php
    }

    /**
     * Refresh WC fragments
     */
    public function refresh_wc_fragments() {
        $item_count = WC()->cart->get_cart_contents_count();

        ob_start();
        wc_get_template( 'tmpl-mini-cart-content.php', array(), '', WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . '/includes/templates/' );
        $cart_item = ob_get_clean();

        // Cart items
        $fragments['div.wpbforwpbakery_cart_content_container'] = '<div class="wpbforwpbakery_cart_content_container">'.$cart_item.'</div>';

        // Cart cunter
        $fragments['span.wpbforwpbakery_mini_cart_counter'] = '<span class="wpbforwpbakery_mini_cart_counter">'.$item_count.'</span>';

        return $fragments;
    }
}

new Side_Mini_Cart();