<?php
/**
 * Plugin Name: WC Builder Pro - WooCommerce Page Builder for WPBakery
 * Description: The WooCommerce addons for WPBakery page builder plugin for WordPress.
 * Plugin URI: 	https://www.persianscript.ir
 * Version: 	2.0.2
 * Author: 		پرشین اسکریپت
 * Author URI: 	https://www.persianscript.ir
 * License:  	GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: wpbforwpbakerypro
 * Domain Path: /languages
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

define( 'WPBFORWPBAKERY_PRO_VERSION', '2.0.2' );
define( 'WPBFORWPBAKERY_PRO_ADDONS_PL_URL', plugins_url( '/', __FILE__ ) );
define( 'WPBFORWPBAKERY_PRO_ADDONS_PL_PATH', plugin_dir_path( __FILE__ ) );
define( 'WPBFORWPBAKERY_PRO_ADDONS_PL_ROOT', __FILE__ );

/**
 * Deactivate the free plugin
 */
register_activation_hook( WPBFORWPBAKERY_PRO_ADDONS_PL_ROOT, 'wpbforwpbakerypro_activation_hook' );
function wpbforwpbakerypro_activation_hook(){
    if ( ! function_exists('is_plugin_active') ){ 
        include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
    }

    if( is_plugin_active('wc-builder/wc-builder.php') ){
        add_action('update_option_active_plugins', function(){
            deactivate_plugins('wc-builder/wc-builder.php');
        });
    }
}

/**
 * Define text domain path
 */
function wpbforwpbakerypro_load_textdomain() {
    load_plugin_textdomain( 'wpbforwpbakerypro', false, basename(WPBFORWPBAKERY_PRO_ADDONS_PL_URL) . '/languages/' );
}
add_action( 'init', 'wpbforwpbakerypro_load_textdomain' );

// Including the core file for secutiry purpose
if ( !function_exists( 'is_plugin_active' ) ) {
    include_once ABSPATH . 'wp-admin/includes/plugin.php';
}

/**
 * Include plugin files
 */
require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/helper-functions.php';
require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/activation-notice.php';

if(is_admin()){
  require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/admin/recommended-plugins/class.recommended-plugins.php';
  require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/admin/recommended-plugins/recommendations.php';
}

// Once we get here, We have passed all validation checks so we can safely include our plugin
require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/WCBuilderPro.php';
require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/custom-posts.php';
require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/admin/admin-init.php';
require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/custom-metabox.php';
require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/woo-config.php';

if( wpbforwpbakerypro_get_option('ajaxcart_singleproduct', 'wpbforwpbakery_other_tabs') === 'on' ){
    require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/single-add-to-cart-ajax.php';
}

if( wpbforwpbakerypro_get_option('single_product_sticky_add_to_cart', 'wpbforwpbakery_other_tabs') === 'on'){
    require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/single-sticky-add-to-cart.php';
}

if( wpbforwpbakerypro_get_option('mini_side_cart', 'wpbforwpbakery_other_tabs') === 'on'){
    require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'includes/class.side-mini-cart.php';
}

add_action('plugins_loaded', 'wpbforwpbakerypro_initialize_plugin', 15);
function wpbforwpbakerypro_initialize_plugin(){
	require_once WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'init.php';
}

// enqueue scripts
add_action( 'wp_enqueue_scripts','wpbforwpbakerypro_enqueue_scripts');
function  wpbforwpbakerypro_enqueue_scripts(){
    // enqueue styles
    wp_enqueue_style( 'wpbforwpbakery-main', WPBFORWPBAKERY_PRO_ADDONS_PL_URL.'/assets/css/main.css', array(), WPBFORWPBAKERY_PRO_VERSION );

   // dynamic style
   $site_width = wpbforwpbakerypro_get_option( 'content_width', 'wpbforwpbakery_woo_template_tabs', '1170' );
   $data = '';
   if($site_width){
   	   $data = "
   			.wpbforwpbakerypro_archive .vc_row.wpb_row.vc_row-fluid,
   			.wpbforwpbakery-single-product .vc_row.wpb_row.vc_row-fluid,
   			.wpbforwpbakerypro-page-template .vc_row.wpb_row.vc_row-fluid{
   				max-width: $site_width;
   				margin: 0 auto;
   			}
   			.wpbforwpbakerypro_archive .vc_row.wpb_row.vc_row-fluid[data-vc-full-width='true'],
   			.wpbforwpbakery-single-product .vc_row.wpb_row.vc_row-fluid[data-vc-full-width='true'],
   			.wpbforwpbakerypro-page-template .vc_row.wpb_row.vc_row-fluid[data-vc-full-width='true']{
				max-width:100%;
   			}
   	   ";
   }
   wp_add_inline_style( 'wpbforwpbakery-main', $data );
}

// set vc editor to post type
add_action('plugins_loaded', 'wpbforwpbakerypro_fire_vc_before_init');
function wpbforwpbakerypro_fire_vc_before_init(){
	add_action('vc_before_init', 'wpbforwpbakerypro_set_post_type_to_vc_editor');
}

function wpbforwpbakerypro_set_post_type_to_vc_editor(){
	if (function_exists('vc_set_default_editor_post_types')) {
		vc_set_default_editor_post_types(array('page', 'post', 'wpbfwpb_template'));
	}
}
